%bcond_without tests
%bcond_with doc

%global srcname pip
%global base_version 25.1.1
%global upstream_version %{base_version}%{?prerel}
%global python_wheel_name %{srcname}-%{upstream_version}-py3-none-any.whl

%{!?bash_completions_dir: %global bash_completions_dir %{_datadir}/bash-completion/completions}

Name:           python-%{srcname}
Version:        %{base_version}%{?prerel:~%{prerel}}
Release:        %mkrel 1
Group:          Development/Python
Summary:        A tool for installing and managing Python packages
License:        MIT
URL:            https://pypi.python.org/pypi/pip
Source0:        https://github.com/pypa/pip/archive/%{version}/%{srcname}-%{version}.tar.gz

BuildArch:      noarch

%if %{with tests}
BuildRequires:  git-core
BuildRequires:  mercurial
BuildRequires:  breezy
BuildRequires:  subversion
BuildRequires:  python-setuptools-wheel
BuildRequires:  python-wheel-wheel
%endif

# Prevent removing of the system packages installed under /usr/lib
# when pip install -U is executed.
# https://bugzilla.redhat.com/show_bug.cgi?id=1550368#c24
# Could be replaced with https://www.python.org/dev/peps/pep-0668/
Patch3:         remove-existing-dist-only-if-path-conflicts.patch

# Use the system level root certificate instead of the one bundled in certifi
# https://bugzilla.redhat.com/show_bug.cgi?id=1655253
# The same patch is a part of the RPM-packaged python-certifi
Patch4:          dummy-certifi.patch

# Don't warn the user about pip._internal.main() entrypoint
# In Fedora, we use that in ensurepip and users cannot do anything about it,
# this warning is juts moot. Also, the warning breaks CPython test suite.
Patch5:         nowarn-pip._internal.main.patch

# Remove -s from Python shebang - ensure that packages installed with pip
# to user locations are seen by pip itself
%undefine _py3_shebang_s

%description
pip is a package management system used to install and manage software packages
written in Python. Many packages can be found in the Python Package Index
(PyPI). pip is a recursive acronym that can stand for either "Pip Installs
Packages" or "Pip Installs Python".



%package -n python3-pip
Summary:        A tool for installing and managing Python3 packages
Group:          Development/Python
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-wheel
%{?python_provide:%python_provide python3-%{srcname}}
Requires:       ca-certificates

%description -n python3-pip
pip is a package management system used to install and manage software packages
written in Python. Many packages can be found in the Python Package Index
(PyPI). pip is a recursive acronym that can stand for either "Pip Installs
Packages" or "Pip Installs Python".

%if %{with doc}
%package doc
Summary:        A documentation for a tool for installing and managing Python packages

BuildRequires:  python%{python3_pkgversion}-sphinx
BuildRequires:  python%{python3_pkgversion}-sphinx-inline-tabs
BuildRequires:  python%{python3_pkgversion}-sphinx-copybutton
BuildRequires:  python%{python3_pkgversion}-myst-parser
BuildRequires:  python%{python3_pkgversion}-sphinx-theme-furo
BuildRequires:  python%{python3_pkgversion}-sphinxcontrib-towncrier

%description doc
A documentation for a tool for installing and managing Python packages.

%endif
%package wheel
Summary:        The pip wheel
Requires:       ca-certificates

%description wheel
A Python wheel of pip to use with venv.

%prep
%autosetup -p1 -n %{srcname}-%{upstream_version}

# this goes together with patch4
rm src/pip/_vendor/certifi/*.pem

# Do not use furo as HTML theme in docs
# furo is not available in Fedora
# but available in Mageia
#sed -i '/html_theme = "furo"/d' docs/html/conf.py

# towncrier extension for Sphinx is not yet available in Fedora
# but available in Mageia
#sed -i '/"sphinxcontrib.towncrier",/d' docs/html/conf.py

# tests expect wheels in here
ln -s %{python_wheel_dir} tests/data/common_wheels

# Remove windows executable binaries
rm -v src/pip/_vendor/distlib/*.exe
sed -i '/\.exe/d' pyproject.toml

# Remove RIGHT-TO-LEFT OVERRIDE from AUTHORS.txt
# https://github.com/pypa/pip/pull/12046
%{python3} -c 'from pathlib import Path; p = Path("AUTHORS.txt"); p.write_text("".join(c for c in p.read_text() if c != "\u202e"))'

# Remove unused test requirements
sed -Ei '/(pytest-(cov|xdist|rerunfailures)|proxy\.py)/d' tests/requirements.txt


%if %{with tests}
%generate_buildrequires
# we only use this to generate test requires
# the "pyproject" part is explicitly disabled as it generates a requirement on pip
%pyproject_buildrequires -N tests/requirements.txt
%endif


%build
export PYTHONPATH=./src/
%pyproject_wheel

%if %{with doc}
# from tox.ini
sphinx-build-3 -b html docs/html docs/build/html
sphinx-build-3 -b man  docs/man  docs/build/man  -c docs/html
rm -rf docs/build/html/{.doctrees,.buildinfo}
%endif


%install
export PYTHONPATH=./src/
%pyproject_install
%pyproject_save_files -l pip

%if %{with doc}
pushd docs/build/man
install -d %{buildroot}%{_mandir}/man1
for MAN in *1; do
install -pm0644 $MAN %{buildroot}%{_mandir}/man1/$MAN
for pip in "pip3" "pip-3" "pip%{python3_version}" "pip-%{python3_version}"; do
echo ".so $MAN" > %{buildroot}%{_mandir}/man1/${MAN/pip/$pip}
done
done
popd
%endif

mkdir -p %{buildroot}%{bash_completions_dir}
PYTHONPATH=%{buildroot}%{python3_sitelib} \
    %{buildroot}%{_bindir}/pip completion --bash \
    > %{buildroot}%{bash_completions_dir}/pip3

# Make bash completion apply to all the 5 symlinks we install
sed -i -e "s/^\\(complete.*\\) pip\$/\\1 pip pip{,-}{3,%{python3_version}}/" \
    -e s/_pip_completion/_pip3_completion/ \
    %{buildroot}%{bash_completions_dir}/pip3


# Provide symlinks to executables to comply with Fedora guidelines for Python
ln -s ./pip%{python3_version} %{buildroot}%{_bindir}/pip-%{python3_version}
ln -s ./pip-%{python3_version} %{buildroot}%{_bindir}/pip-3


mkdir -p %{buildroot}%{python_wheel_dir}
install -p %{_pyproject_wheeldir}/%{python_wheel_name} -t %{buildroot}%{python_wheel_dir}


%check
%if ! 0%{?mageia}
# Verify bundled provides are up to date
%{_rpmconfigdir}/pythonbundles.py src/pip/_vendor/vendor.txt --compare-with '%{bundled 3}'
%endif

# Verify no unwanted files are present in the package
grep "exe$" %{pyproject_files} && exit 1 || true
grep "pem$" %{pyproject_files} && exit 1 || true

# Verify we can at least run basic commands without crashing
%{py3_test_envvars} %{buildroot}%{_bindir}/pip --help
%{py3_test_envvars} %{buildroot}%{_bindir}/pip list
%{py3_test_envvars} %{buildroot}%{_bindir}/pip show pip

%if %{with tests}
# Upstream tests
# bash completion tests only work from installed package
pytest_k='not completion'

# --ignore'd tests are not compatible with the latest virtualenv
# These files contain almost 500 tests so we should enable them back
# as soon as pip will be compatible upstream
# https://github.com/pypa/pip/pull/8441
# among them, tests/functional/test_proxy.py needs proxy.py which is not
# yet packaged in Fedora
%pytest -m 'not network' -k "$(echo $pytest_k)" \
    --ignore tests/functional --ignore tests/lib/test_lib.py
%endif

%files -n python3-pip -f %{pyproject_files}
%doc README.rst
%if %{with doc}
%{_mandir}/man1/pip.*
%{_mandir}/man1/pip-*.*
%{_mandir}/man1/pip3.*
%{_mandir}/man1/pip3-*.*
%endif
%{_bindir}/pip
%{_bindir}/pip3
%{_bindir}/pip-3
%{_bindir}/pip%{python3_version}
%{_bindir}/pip-%{python3_version}
%dir %{bash_completions_dir}
%{bash_completions_dir}/pip3

%if %{with doc}
%files doc
%license LICENSE.txt
%doc README.rst
%doc docs/build/html
%endif

%files wheel
%license LICENSE.txt
# we own the dir for simplicity
%dir %{python_wheel_dir}/
%{python_wheel_dir}/%{python_wheel_name}


%changelog
* Wed Jun 04 2025 daviddavid <daviddavid> 25.1.1-1.mga10
+ Revision: 2188122
- new version: 25.1.1

* Wed Apr 09 2025 daviddavid <daviddavid> 25.0.1-1.mga10
+ Revision: 2174295
- new version: 25.0.1

* Thu Feb 20 2025 wally <wally> 24.3.1-2.mga10
+ Revision: 2150144
- bootstrap build for python3.13

* Sat Dec 14 2024 wally <wally> 24.3.1-1.mga10
+ Revision: 2125063
- new version 24.3.1

* Thu Aug 08 2024 wally <wally> 24.2-1.mga10
+ Revision: 2084245
- new version 24.2 (sync with Fedora where appropriate)

* Tue Feb 20 2024 wally <wally> 24.0-1.mga10
+ Revision: 2042698
- new version 24.0

* Thu Dec 07 2023 wally <wally> 23.3.1-2.mga10
+ Revision: 2014568
- bootstrap build for py3.12 update

* Sat Nov 25 2023 wally <wally> 23.3.1-1.mga10
+ Revision: 2009570
- new version 23.3.1

* Sun Apr 16 2023 wally <wally> 23.0.1-1.mga9
+ Revision: 1953075
- new version 23.0.1
- drop unneeded conflicts

* Fri Apr 14 2023 kekepower <kekepower> 22.3.1-4.mga9
+ Revision: 1952989
- Add Conflicts to remove the file /pip3

* Fri Apr 14 2023 papoteur <papoteur> 22.3.1-3.mga9
+ Revision: 1952967
-fix location of completions/pip3, was in /

* Thu Mar 09 2023 daviddavid <daviddavid> 22.3.1-2.mga9
+ Revision: 1948463
- add patch to fix compatibility with Sphinx 6.0

* Sat Dec 10 2022 wally <wally> 22.3.1-1.mga9
+ Revision: 1920341
- new version 22.3.1

* Wed Aug 10 2022 wally <wally> 22.2.2-1.mga9
+ Revision: 1876719
- new version 22.2.2
- sync with Fedora where appropriate

* Fri Apr 08 2022 wally <wally> 22.0.4-1.mga9
+ Revision: 1848128
- new version 22.0.4

* Tue Mar 29 2022 umeabot <umeabot> 21.3.1-3.mga9
+ Revision: 1831643
- Mageia 9 Mass Rebuild

* Sat Feb 05 2022 wally <wally> 21.3.1-2.mga9
+ Revision: 1771763
- sync with Fedora where appropriate
- bootstrap build for python 3.10

* Sun Nov 07 2021 wally <wally> 21.3.1-1.mga9
+ Revision: 1754384
- new version 21.3.1

* Sun Sep 12 2021 wally <wally> 21.2.3-1.mga9
+ Revision: 1745338
- new version 21.2.3

* Fri Jul 23 2021 luigiwalser <luigiwalser> 21.1.3-2.mga9
+ Revision: 1737507
- add patch to fix CVE-2021-33503

* Tue Jul 13 2021 wally <wally> 21.1.3-1.mga9
+ Revision: 1735923
- new version 21.1.3

* Sun Jun 27 2021 luigiwalser <luigiwalser> 21.1.2-1.mga9
+ Revision: 1734028
- 21.1.2

* Sun May 30 2021 wally <wally> 21.1.1-1.mga9
+ Revision: 1728924
- new version 21.1.1 (sync with Fedora where appropriate)

* Sun Mar 14 2021 wally <wally> 20.3.3-5.mga9
+ Revision: 1702611
- disable bootstrap

* Sun Mar 14 2021 wally <wally> 20.3.3-4.mga9
+ Revision: 1702515
- bootstrap build for new python 3.9

* Tue Dec 22 2020 wally <wally> 20.3.3-3.mga8
+ Revision: 1662954
- sync patches and .spec with Fedora where appropriate

* Tue Dec 22 2020 wally <wally> 20.3.3-2.mga8
+ Revision: 1662913
- add a patch from upstream pull request to verify built wheel contains valid metadata

* Fri Dec 18 2020 wally <wally> 20.3.3-1.mga8
+ Revision: 1660905
- new version 20.3.3

* Mon Jul 20 2020 wally <wally> 20.1.1-1.mga8
+ Revision: 1607441
- new version 20.1.1
- sync with Fedora where appropriate

* Sun Jul 05 2020 joequant <joequant> 19.3.1-4.mga8
+ Revision: 1602284
- fix bootstrap

* Fri Feb 28 2020 wally <wally> 19.3.1-3.mga8
+ Revision: 1552019
- add patch from Fedora to make new pip to support the old private API of main()

* Wed Feb 19 2020 umeabot <umeabot> 19.3.1-2.mga8
+ Revision: 1544152
- Mageia 8 Mass Rebuild

* Fri Jan 24 2020 daviddavid <daviddavid> 19.3.1-1.mga8
+ Revision: 1482649
- new version: 19.3.1

* Wed Oct 02 2019 daviddavid <daviddavid> 19.2.3-1.mga8
+ Revision: 1448789
- new version: 19.2.3
- drop patch that should strip path prefixes from RECORD files, the paths are relative

* Tue Sep 03 2019 wally <wally> 19.1.1-3.mga8
+ Revision: 1436774
- non-bootstrap build for python3.8

* Tue Sep 03 2019 wally <wally> 19.1.1-2.mga8
+ Revision: 1436755
- bootstrap build for python3.8
- drop python2 support

* Sun Jul 07 2019 daviddavid <daviddavid> 19.1.1-1.mga8
+ Revision: 1419305
- new version: 19.1.1

* Tue Mar 05 2019 guillomovitch <guillomovitch> 19.0.3-1.mga7
+ Revision: 1371724
- new version 19.0.3

* Fri Jan 04 2019 wally <wally> 18.1-5.mga7
+ Revision: 1349231
- disable bootstrap

* Fri Jan 04 2019 wally <wally> 18.1-4.mga7
+ Revision: 1349202
- another bootstrap build for python3.7

* Fri Jan 04 2019 wally <wally> 18.1-3.mga7
+ Revision: 1349196
- disable bootstrap
- bootstrap build for python3.7

* Tue Jan 01 2019 wally <wally> 18.1-1.mga7
+ Revision: 1348163
- new version 18.1 (sync a bit with Fedora)
- create python-pip-wheel

* Tue Sep 25 2018 tv <tv> 9.0.3-5.mga7
+ Revision: 1304900
- rebuild with wheel

* Tue Sep 25 2018 tv <tv> 9.0.3-4.mga7
+ Revision: 1304876
- fix BR for bootstrapping: pythonXdist(*) -> pythonX-* + disable wheel again
- fix BR for bootstrapping: python3dist(setuptools) -> python3-setuptools
- fix BR for bootstrapping: python2dist(setuptools) -> python2-setuptools
- rebuild with wheel

* Mon Sep 24 2018 tv <tv> 9.0.3-3.mga7
+ Revision: 1303663
- rebuild w/o wheel

* Thu Sep 20 2018 umeabot <umeabot> 9.0.3-2.mga7
+ Revision: 1289670
- Mageia 7 Mass Rebuild

* Sat Mar 31 2018 kekepower <kekepower> 9.0.3-1.mga7
+ Revision: 1213726
- Update to version 9.0.3
- Renamed python-pip to python2-pip
- Use python_provide

* Sat Jul 29 2017 philippem <philippem> 9.0.1-2.mga7
+ Revision: 1132538
- try to force python-pkg-resources version
- fix typo missing %
- Rebuild for Python 3.6 with wheel

* Sat Jul 29 2017 philippem <philippem> 9.0.1-1.mga7
+ Revision: 1132498
- Remove setup.py test support and python_requires
- Remove setup.py test support (from upstream)
- Remove setup.py test support (from upstream)
- upgrade to 9.0.1, first step for Python 3.6.2
- revert to r929830, keep pip 8.0.2

* Sat May 27 2017 philippem <philippem> 8.0.3-1.mga6
+ Revision: 1105186
- update to 8.0.3
+ joequant <joequant>
- added comment

* Mon Feb 01 2016 joequant <joequant> 8.0.2-6.mga6
+ Revision: 929686
- rebuild for wheel

* Mon Feb 01 2016 joequant <joequant> 8.0.2-5.mga6
+ Revision: 929685
- bump in queue
- fix wheel breakage - bootstrap
+ philippem <philippem>
- enable wheel

* Thu Jan 28 2016 philippem <philippem> 8.0.2-2.mga6
+ Revision: 928459
- need to re bootstrap
- enable patch for wheel

* Sun Jan 24 2016 joequant <joequant> 8.0.2-1.mga6
+ Revision: 926779
- upgrade to 8.0.2

* Wed Oct 07 2015 tv <tv> 7.1.2-5.mga6
+ Revision: 886741
- rebuild for python 3.5

* Wed Oct 07 2015 joequant <joequant> 7.1.2-4.mga6
+ Revision: 886675
- upgrade to 3.5

* Wed Sep 23 2015 philippem <philippem> 7.1.2-3.mga6
+ Revision: 882298
- Rebuild as wheel for Python 3.5

* Tue Sep 22 2015 philippem <philippem> 7.1.2-2.mga6
+ Revision: 882272
- rebuild without wheel, first step for Python 3.5

* Sun Aug 30 2015 joequant <joequant> 7.1.2-1.mga6
+ Revision: 871364
- upgrade to 7.1.2

* Sat Aug 22 2015 joequant <joequant> 7.1.1-1.mga6
+ Revision: 868008
- upgrade to 7.1.1

* Sun Aug 02 2015 joequant <joequant> 7.1.0-1.mga6
+ Revision: 860857
- upgrade to 7.1.0

* Tue Apr 28 2015 philippem <philippem> 6.1.1-2.mga5
+ Revision: 820817
- update to 6.1.1 fix mga#15748

* Wed Jan 07 2015 philippem <philippem> 1.5.6-8.mga5
+ Revision: 809189
- fix CVE-2014-8991 mga#14969

* Wed Oct 15 2014 umeabot <umeabot> 1.5.6-7.mga5
+ Revision: 739105
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.5.6-6.mga5
+ Revision: 729320
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 1.5.6-5.mga5
+ Revision: 688216
- Mageia 5 Mass Rebuild

* Tue Jun 03 2014 philippem <philippem> 1.5.6-4.mga5
+ Revision: 632194
- add egg provides

* Sat May 31 2014 pterjan <pterjan> 1.5.6-3.mga5
+ Revision: 628885
- Rebuild for new Python

* Sat May 24 2014 philippem <philippem> 1.5.6-2.mga5
+ Revision: 625292
- Rebuild as wheel for Python 3.4

* Fri May 23 2014 philippem <philippem> 1.5.6-1.mga5
+ Revision: 625238
- update to 1.5.6, first step for Python 3.4

* Sun Apr 20 2014 philippem <philippem> 1.5.4-1.mga5
+ Revision: 617149
- update to 1.5.4

* Sun Dec 01 2013 philippem <philippem> 1.4.1-4.mga4
+ Revision: 554518
- change-match_hostname-to-follow-RFC-6125 (mga#11785)

* Tue Oct 22 2013 umeabot <umeabot> 1.4.1-3.mga4
+ Revision: 543939
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1.4.1-2.mga4
+ Revision: 499119
- Rebuild to add different pythonegg provides for python 2 and 3

* Mon Sep 23 2013 joequant <joequant> 1.4.1-1.mga4
+ Revision: 484288
- update to 1.4.1

* Fri Jul 26 2013 philippem <philippem> 1.3.1-3.mga4
+ Revision: 458721
- Fix for CVE 2013-2099
- Add Python 3

* Wed May 08 2013 neoclust <neoclust> 1.3.1-2.mga3
+ Revision: 412711
- fix proxy support
- New version ( fix CVE-2013-1888 ) mga #10007)

* Tue Mar 05 2013 neoclust <neoclust> 1.2.1-2.mga3
+ Revision: 401418
- Add missing deps ( mga #9246 )

* Mon Jan 28 2013 joequant <joequant> 1.2.1-1.mga3
+ Revision: 392901
- imported package python-pip

